import glob
import setuptools


setuptools.setup(
    name='handout',
    version='0.2.1',
    description='Add Markdown text and inline figures to your Python script.',
    url='http://github.com/danijar/handout',
    install_requires=[],
    packages=['handout'],
    data_files=[('handout', glob.glob('handout/data/*'))],
    classifiers=[
        'Programming Language :: Python :: 3',
        'Topic :: Scientific/Engineering :: Visualization',
        'Topic :: Multimedia :: Graphics :: Presentation',
        'License :: OSI Approved :: Apache Software License',
    ],
)
